pref("distribution.searchplugins.defaultLocale", "en-US");
// Forbid application updates
pref("app.update.enabled", false, locked);

pref("devtools.webide.autoinstallADBHelper", false);
pref("devtools.webide.autoinstallFxdtAdapters", false);

pref("extensions.unsignedScopes", 12);

pref("spellchecker.dictionary_path", "/usr/share/hunspell");
